.. django-wysiwyg documentation master file, created by
   sphinx-quickstart on Wed Apr  6 10:47:56 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-wysiwyg's documentation!
==========================================

Contents:

.. toctree::
   :maxdepth: 1
   
   install
   examples

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

